@@ -11,4 +11,4 @@ import pytest
 class TestCase:
 
     @pytest.fixture(scope="function")
-    def setUp(self, getdriver, flush_browser): ...
+    def setUp(self, getdriver): ...
