@@ -22,6 +22,9 @@ class Page(object):
         self.selector = readElementSource(
             self.getProjectPath() + self.filePath + self.getClassName() + self.suffix).readFileToDict()
 
+    def GetSource(self, key):
+        return self.selector["page"][key]["ele"]
+
     def getProjectPath(self) -> str: ...
 
     @classmethod
@@ -38,7 +41,7 @@ class Page(object):
         methods = list(
             filter(lambda m: not m.startswith("__") and not m.endswith("__") and callable(getattr(cls, m)), dir(cls)))
         methods.pop(methods.index("writeKey"))
-        methods.pop(methods.index("getPorjectPath"))
+        methods.pop(methods.index("getProjectPath"))
         methods.pop(methods.index("getClassName"))
         for i in methods:
             func = getattr(cls, i)
